@@ -38,18 +38,9 @@ class FormBuilder:
                     "Could not find a registered field of type %s" % field_type
                 )
 
-            # check there is a label
-            if "label" not in field_value:
-                raise AttributeError(
-                    "The block for %s must contain a label of type blocks.CharBlock(required=True)"
-                    % field_type
-                )
-
-            # slugify the label for the field name
-            field_name = get_slug_from_string(field_value.get("label"))
-
             # get the field
             registered_cls = registered_fields[field_type]()
+            field_name = registered_cls.get_formfield_name(field_value)
             field_cls = registered_cls.get_formfield(field_value)
             formfields[field_name] = field_cls
 
